@@ -10,7 +10,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT = qw(parse_sim);
 
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # legend: S = lack of samples
 
@@ -95,7 +95,7 @@ Business::ID::SIM - Validate Indonesian driving license number (nomor SIM)
 
 =head1 VERSION
 
-version 0.04
+This document describes version 0.05 of Business::ID::SIM (from Perl distribution Business-ID-SIM), released on 2014-08-16.
 
 =head1 SYNOPSIS
 
@@ -122,10 +122,10 @@ in the SIM number and all SIM's have the same number.
 =head1 FUNCTIONS
 
 
-None are exported by default, but they are exportable.
-
 =head2 parse_sim(%args) -> [status, msg, result, meta]
 
+Validate Indonesian driving license number (nomor SIM).
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -138,7 +138,16 @@ Input to be parsed.
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+ (any)
 
 =head1 HOMEPAGE
 
@@ -162,7 +171,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
